import {Component, Input} from '@angular/core';
import {Character} from '../../project/game-model/characters/Character';
import {MatDialog} from "@angular/material/dialog";
import {
  TemplateSystemEditorComponent
} from "../gamesystem-editor/template-system-editor/template-system-editor.component";
import {GameModel} from "../../project/game-model/GameModel";
import {TemplateType} from "../../project/game-model/gamesystems/TemplateType";
import {Gamesystem} from "../../project/game-model/gamesystems/Gamesystem";
import {SimpleGamesystem} from "../../project/game-model/gamesystems/SimpleGamesystem";
import {ProductGamesystem} from "../../project/game-model/gamesystems/ProductGamesystem";

@Component({
  selector: 'app-character-editor',
  templateUrl: './character-editor.component.html',
  styleUrl: './character-editor.component.scss'
})
export class CharacterEditorComponent {

  @Input() character: Character | undefined
  @Input() gameModel: GameModel | undefined

  constructor(private dialog: MatDialog) {
  }

  openTemplateEditor() {
    const dialogRef = this.dialog.open(TemplateSystemEditorComponent, {
      minWidth: "400px",
      data: this.gameModel!.getTemplateGamesystems(TemplateType.CHARACTER)
    })

    dialogRef.afterClosed().subscribe(res => {
      if(res != undefined) {
        const referenceSystem: Gamesystem<any, any> = res
        if(referenceSystem instanceof SimpleGamesystem) {
          this.character!.addCharacterSpecificSimpleGamesystem(referenceSystem)
        } else if(referenceSystem instanceof ProductGamesystem) {
          this.character!.addCharacterSpecificProductTemplateGamesystem(referenceSystem)
        }
      }
    })
  }
}
